@@ -47,4 +47,6 @@ _S(1029,	"F_CANCELLK" )
 _S(1030,	"F_DUPFD_CLOEXEC" )
 _S(1031,	"F_SETPIPE_SZ" )
 _S(1032,	"F_GETPIPE_SZ" )
+_S(1033,	"F_ADD_SEALS" )
+_S(1034,	"F_GET_SEALS" )
 
