@@ -1,5 +1,5 @@
 /* ip6optnametab.h --
- * Copyright 2013-14 Red Hat Inc., Durham, North Carolina.
+ * Copyright 2013-15 Red Hat Inc., Durham, North Carolina.
  * All Rights Reserved.
  *
  * This library is free software; you can redistribute it and/or
@@ -50,6 +50,13 @@ _S(32, "IPV6_FLOWLABEL_MGR")
 _S(33, "IPV6_FLOWINFO_SEND")
 _S(34, "IPV6_IPSEC_POLICY")
 _S(35, "IPV6_XFRM_POLICY")
+_S(42, "MCAST_JOIN_GROUP")
+_S(43, "MCAST_BLOCK_SOURCE")
+_S(44, "MCAST_UNBLOCK_SOURCE")
+_S(45, "MCAST_LEAVE_GROUP")
+_S(46, "MCAST_JOIN_SOURCE_GROUP")
+_S(47, "MCAST_LEAVE_SOURCE_GROUP")
+_S(48, "MCAST_MSFILTER")
 _S(49, "IPV6_RECVPKTINFO")
 _S(50, "IPV6_PKTINFO")
 _S(51, "IPV6_RECVHOPLIMIT")
