@@ -448,3 +448,6 @@ _S(504, "process_vm_readv")
 _S(505, "process_vm_writev")
 _S(506, "kcmp")
 _S(507, "finit_module")
+_S(508, "sched_setattr")
+_S(509, "sched_getattr")
+_S(510, "renameat2")
