@@ -31,7 +31,11 @@
 #include <stdlib.h>
 #include <string.h>
 #include <sys/stat.h>
-
+#include <sys/personality.h>
+#include <sys/mount.h>
+#ifndef MS_DIRSYNC
+#include <linux/fs.h>
+#endif
 #include "gen_tables.h"
 #include "libaudit.h"
 #include "interpret.h"
@@ -41,6 +45,7 @@
 #define SEMOP            1
 #define SEMGET           2
 #define SEMCTL           3
+#define SEMTIMEDOP       4
 #define MSGSND          11
 #define MSGRCV          12
 #define MSGGET          13
