@@ -144,7 +144,7 @@ static int nv_split(char *buf, struct nv_pair *nv)
 
 	nv->name = NULL;
 	nv->value = NULL;
-	ptr = strtok_r(buf, " ", &saved);
+	ptr = audit_strsplit_r(buf, &saved);
 	if (ptr == NULL)
 		return 0; /* If there's nothing, go to next line */
 	if (ptr[0] == '#')
@@ -152,20 +152,20 @@ static int nv_split(char *buf, struct nv_pair *nv)
 	nv->name = ptr;
 
 	/* Check for a '=' */
-	ptr = strtok_r(NULL, " ", &saved);
+	ptr = audit_strsplit_r(NULL, &saved);
 	if (ptr == NULL)
 		return 1;
 	if (strcmp(ptr, "=") != 0)
 		return 2;
 
 	/* get the value */
-	ptr = strtok_r(NULL, " ", &saved);
+	ptr = audit_strsplit_r(NULL, &saved);
 	if (ptr == NULL)
 		return 1;
 	nv->value = ptr;
 
 	/* Make sure there's nothing else */
-	ptr = strtok_r(NULL, " ", &saved);
+	ptr = audit_strsplit_r(NULL, &saved);
 	if (ptr)
 		return 1;
 
@@ -396,7 +396,7 @@ int audit_is_enabled(int fd)
 		   and disable the audit system get in. ECONNREFUSED is
 		   issued by the kernel when there is "no on listening". */
 		return 0;
-	} else if (rc == -EPERM && getuid() != 0) {
+	} else if (rc == -EPERM && geteuid() != 0) {
 		/* If we get this, then the kernel supports auditing
 		 * but we don't have enough privilege to write to the
 		 * socket. Therefore, we have already been authenticated
@@ -493,6 +493,24 @@ int audit_set_backlog_limit(int fd, uint32_t limit)
 	return rc;
 }
 
+int audit_set_backlog_wait_time(int fd, uint32_t bwt)
+{
+	int rc = -1;
+#if HAVE_DECL_AUDIT_VERSION_BACKLOG_WAIT_TIME
+	struct audit_status s;
+
+	memset(&s, 0, sizeof(s));
+	s.mask          = AUDIT_STATUS_BACKLOG_WAIT_TIME;
+	s.backlog_wait_time = bwt;
+	rc = audit_send(fd, AUDIT_SET, &s, sizeof(s));
+	if (rc < 0)
+		audit_msg(audit_priority(errno),
+			"Error sending backlog limit request (%s)", 
+			strerror(-rc));
+#endif
+	return rc;
+}
+
 int audit_set_feature(int fd, unsigned feature, unsigned value, unsigned lock)
 {
 #if HAVE_DECL_AUDIT_FEATURE_VERSION
@@ -1186,18 +1204,19 @@ int audit_determine_machine(const char *arch)
 #ifdef WITH_ARM
 		case MACH_ARM:
 			if (bits == __AUDIT_ARCH_64BIT)
-				return -6;
+				return -6; // Deadcode - just incase of mistake
 			break;
 #endif
 #ifdef WITH_AARCH64
 		case MACH_AARCH64:
-			if (bits != __AUDIT_ARCH_64BIT)
+			if (bits && bits != __AUDIT_ARCH_64BIT)
 				return -6;
 			break;
 #endif
-		case MACH_86_64: /* fallthrough */
-		case MACH_PPC64: /* fallthrough */
-		case MACH_S390X: /* fallthrough */
+		case MACH_86_64:   /* fallthrough */
+		case MACH_PPC64:   /* fallthrough */
+		case MACH_PPC64LE: /* fallthrough */
+		case MACH_S390X:   /* fallthrough */
 			break;
 		default:
 			return -6;
@@ -1283,7 +1302,6 @@ int audit_rule_fieldpair_data(struct audit_rule_data **rulep, const char *pair,
 		case AUDIT_FSUID:
 		case AUDIT_LOGINUID:
 		case AUDIT_OBJ_UID:
-		case AUDIT_OBJ_GID:
 			// Do positive & negative separate for 32 bit systems
 			vlen = strlen(v);
 			if (isdigit((char)*(v))) 
@@ -1309,6 +1327,7 @@ int audit_rule_fieldpair_data(struct audit_rule_data **rulep, const char *pair,
 		case AUDIT_EGID:
 		case AUDIT_SGID:
 		case AUDIT_FSGID:
+		case AUDIT_OBJ_GID:
 			if (isdigit((char)*(v))) 
 				rule->values[rule->field_count] = 
 					strtol(v, NULL, 0);
