@@ -1,5 +1,5 @@
 /* libaudit.h -- 
- * Copyright 2004-2014 Red Hat Inc., Durham, North Carolina.
+ * Copyright 2004-2015 Red Hat Inc., Durham, North Carolina.
  * All Rights Reserved.
  *
  * This library is free software; you can redistribute it and/or
@@ -93,6 +93,9 @@ extern "C" {
 #define AUDIT_SERVICE_STOP	1131	/* Service (daemon) stop */
 #define AUDIT_GRP_MGMT		1132	/* Group account attr was modified */
 #define AUDIT_GRP_CHAUTHTOK	1133	/* Group acct password or pin changed */
+#define AUDIT_MAC_CHECK		1134    /* User space MAC decision results */
+#define AUDIT_ACCT_LOCK		1135    /* User's account locked by admin */
+#define AUDIT_ACCT_UNLOCK	1136    /* User's account unlocked by admin */
 
 #define AUDIT_FIRST_DAEMON	1200
 #define AUDIT_LAST_DAEMON	1299
@@ -200,6 +203,10 @@ extern "C" {
 #define AUDIT_CRYPTO_REPLAY_USER	2406 /* Crypto replay detected */
 #define AUDIT_CRYPTO_SESSION		2407 /* Record parameters set during
 						TLS session establishment */
+#define AUDIT_CRYPTO_IKE_SA		2408 /* Record parameters related to
+						IKE SA */
+#define AUDIT_CRYPTO_IPSEC_SA		2409 /* Record parameters related to
+						IPSEC SA */
 
 #define AUDIT_LAST_CRYPTO_MSG		2499
 
@@ -397,7 +404,7 @@ struct audit_reply {
 	struct audit_status     *status;
 	struct audit_rule_data  *ruledata;
 	struct audit_login      *login;
-	const char              *message;
+	char                    *message;
 	struct nlmsgerr         *error;
 	struct audit_sig_info   *signal_info;
 	struct daemon_conf      *conf;
