@@ -128,8 +128,12 @@ static void usage(void)
      "    -v                  Version\n"
      "    -w <path>           Insert watch at <path>\n"
      "    -W <path>           Remove watch at <path>\n"
+#if HAVE_DECL_AUDIT_FEATURE_VERSION
      "    --loginuid-immutable   Make loginuids unchangeable once set\n"
+#endif
+#if HAVE_DECL_AUDIT_VERSION_BACKLOG_WAIT_TIME
      "    --backlog_wait_time    Set the kernel backlog_wait_time\n"
+#endif
      );
 }
 
@@ -482,7 +486,7 @@ int report_status(int fd)
 int parse_syscall(struct audit_rule_data *rule_new, const char *optarg)
 {
 	int retval = 0;
-	char *saved = NULL;
+	char *saved;
 
 	if (strchr(optarg, ',')) {
 		char *ptr, *tmp = strdup(optarg);
@@ -511,8 +515,12 @@ int parse_syscall(struct audit_rule_data *rule_new, const char *optarg)
 
 struct option long_opts[] =
 {
+#if HAVE_DECL_AUDIT_FEATURE_VERSION
   {"loginuid-immutable", 0, NULL, 1},
+#endif
+#if HAVE_DECL_AUDIT_VERSION_BACKLOG_WAIT_TIME
   {"backlog_wait_time", 1, NULL, 2},
+#endif
   {NULL, 0, NULL, 0}
 };
 
@@ -551,6 +559,22 @@ static int setopt(int count, int lineno, char *vars[])
 		retval = -2;
 		break;
         case 's':
+		if (count > 3) {
+			audit_msg(LOG_ERR,
+				"Too many options for status command");
+			retval = -1;
+			break;
+		} else if (optind == 2 && count == 3) { 
+			if (strcmp(vars[optind], "-i") == 0) {
+				interpret = 1;
+				count -= 1;
+			} else {
+				audit_msg(LOG_ERR,
+					"Only -i option is allowed");
+				retval = -1;
+				break;
+			}
+		}
 		retval = report_status(fd);
 		break;
         case 'e':
@@ -830,11 +854,22 @@ static int setopt(int count, int lineno, char *vars[])
 			audit_msg(LOG_ERR,
 	  "The -m option must be only the only option and takes 1 parameter");
 			retval = -1;
-		} else if (audit_log_user_message( fd, AUDIT_USER,
+		} else {
+			const char*s = optarg;
+			while (*s) {
+				if (*s < 32) {
+					audit_msg(LOG_ERR,
+					"Illegal character in audit event");
+					return -1;
+				}
+				s++;
+			}
+			if (audit_log_user_message( fd, AUDIT_USER,
 					optarg, NULL, NULL, NULL, 1) <= 0)
 			retval = -1;
 		else
 			return -2;  // success - no reply for this
+		}
 		break;
 	case 'R':
 		audit_msg(LOG_ERR, "Error - nested rule files not supported");
