@@ -25,12 +25,24 @@
 #define AUDITD_EVENT_H
 
 #include "libaudit.h"
+
+typedef void (*ack_func_type)(void *ack_data, const unsigned char *header, const char *msg);
+
+struct auditd_reply_list {
+	struct audit_reply reply;
+	struct auditd_reply_list *next;
+	ack_func_type ack_func;
+	void *ack_data;
+	unsigned long sequence_id;
+};
+
 #include "auditd-config.h"
 
 void shutdown_events(void);
 int init_event(struct daemon_conf *config);
 void resume_logging(void);
 void enqueue_event(struct auditd_reply_list *rep);
+void enqueue_formatted_event(char *msg, ack_func_type ack_func, void *ack_data, uint32_t sequence_id);
 void *consumer_thread_main(void *arg);
 
 #endif
