@@ -81,7 +81,7 @@ enum {  R_INFILE, R_TIME_END, R_TIME_START, R_VERSION, R_SUMMARY, R_LOG_TIMES,
 	R_AVCS, R_SYSCALLS, R_PIDS, R_EVENTS, R_ACCT_MODS,  
 	R_INTERPRET, R_HELP, R_ANOMALY, R_RESPONSE, R_SUMMARY_DET, R_CRYPTO,
 	R_MAC, R_FAILED, R_SUCCESS, R_ADD, R_DEL, R_AUTH, R_NODE, R_IN_LOGS,
-	R_KEYS, R_TTY, R_NO_CONFIG };
+	R_KEYS, R_TTY, R_NO_CONFIG, R_COMM, R_VIRT, R_INTEG };
 
 static struct nv_pair optiontab[] = {
 	{ R_AUTH, "-au" },
@@ -90,6 +90,7 @@ static struct nv_pair optiontab[] = {
 	{ R_AVCS, "--avc" },
 	{ R_ADD, "--add" },
 	{ R_CONFIGS, "-c" },
+	{ R_COMM, "--comm" },
 	{ R_CONFIGS, "--config" },
 	{ R_CRYPTO, "-cr" },
 	{ R_CRYPTO, "--crypto" },
@@ -107,6 +108,7 @@ static struct nv_pair optiontab[] = {
 	{ R_INFILE, "-if" },
 	{ R_INFILE, "--input" },
 	{ R_IN_LOGS, "--input-logs" },
+	{ R_INTEG, "--integrity" },
 	{ R_KEYS, "-k" },
 	{ R_KEYS, "--key" },
 	{ R_LOGINS, "-l" },
@@ -142,7 +144,8 @@ static struct nv_pair optiontab[] = {
 	{ R_VERSION, "-v" },
 	{ R_VERSION, "--version" },
 	{ R_EXES, "-x" },
-	{ R_EXES, "--executable" }
+	{ R_EXES, "--executable" },
+	{ R_VIRT, "--virt" }
 };
 #define OPTION_NAMES (sizeof(optiontab)/sizeof(optiontab[0]))
 
@@ -162,6 +165,7 @@ static void usage(void)
 	printf("usage: aureport [options]\n"
 	"\t-a,--avc\t\t\tAvc report\n"
 	"\t-au,--auth\t\t\tAuthentication report\n"
+	"\t--comm\t\t\t\tCommands run report\n"
 	"\t-c,--config\t\t\tConfig change report\n"
 	"\t-cr,--crypto\t\t\tCrypto report\n"
 	"\t-e,--event\t\t\tEvent report\n"
@@ -172,6 +176,7 @@ static void usage(void)
 	"\t-i,--interpret\t\t\tInterpretive mode\n"
 	"\t-if,--input <Input File name>\tuse this file as input\n"
 	"\t--input-logs\t\t\tUse the logs even if stdin is a pipe\n"
+	"\t--integrity\t\t\tIntegrity event report\n"
 	"\t-l,--login\t\t\tLogin report\n"
 	"\t-k,--key\t\t\tKey report\n"
 	"\t-m,--mods\t\t\tModification to accounts report\n"
@@ -191,6 +196,7 @@ static void usage(void)
 	"\t--tty\t\t\t\tReport about tty keystrokes\n"
 	"\t-u,--user\t\t\tUser name report\n"
 	"\t-v,--version\t\t\tVersion\n"
+	"\t--virt\t\t\t\tVirtualization report\n"
 	"\t-x,--executable\t\t\teXecutable name report\n"
 	"\tIf no report is given, the summary report will be displayed\n"
 	);
@@ -289,6 +295,21 @@ int check_params(int count, char *vars[])
 				event_loginuid = 1;
 			}
 			break;
+		case R_INTEG:
+			if (set_report(RPT_INTEG))
+				retval = -1;
+			else { 
+				set_detail(D_DETAILED);
+				event_loginuid = 1;
+			}
+			break;
+		case R_VIRT:
+			if (set_report(RPT_VIRT))
+				retval = -1;
+			else { 
+				set_detail(D_DETAILED);
+			}
+			break;
 		case R_CONFIGS:
 			if (set_report(RPT_CONFIG))
 				retval = -1;
@@ -313,7 +334,7 @@ int check_params(int count, char *vars[])
 				event_exe = dummy;
 				event_hostname = dummy;
 				event_terminal = dummy;
-				event_uid = 1;
+				event_loginuid = 1;
 			}
 			break;
 		case R_ACCT_MODS:
@@ -464,6 +485,21 @@ int check_params(int count, char *vars[])
 				}
 			}
 			break;
+		case R_COMM:
+			if (set_report(RPT_COMM))
+				retval = -1;
+			else {
+				if (!optarg) {
+					set_detail(D_DETAILED);
+					event_terminal = dummy;
+					event_hostname = dummy;
+					event_comm = dummy;
+					event_loginuid = 1;
+				} else {
+					UNIMPLEMENTED;
+				}
+			}
+			break;
 		case R_ANOMALY:
 			if (set_report(RPT_ANOMALY))
 				retval = -1;
@@ -673,6 +709,7 @@ int check_params(int count, char *vars[])
 				event_hostname = dummy;
 				event_terminal = dummy;
 				event_exe = dummy;
+				event_comm = dummy;
 				event_key = dummy;
 				event_loginuid = 1;
 			}
