@@ -138,10 +138,8 @@ void event_free(struct event *event)
 	}
 }
 
-inline char *copy_str(const char *str)
-{
-	return (str) ? strdup(str) : NULL;
-}
+#define copy_str( str ) (str) ? strdup(str) : NULL
+
 
 void usage(FILE *output)
 {
@@ -650,7 +648,7 @@ int process_control_event(auparse_state_t *au)
 	return 0;
 }
 
-inline int is_resource(const char *res)
+static int is_resource(const char *res)
 {
 	if (res == NULL ||
 	    res[0] == '\0' ||
